@@ -1,14 +1,16 @@
-subroutine recurse(fy,xispd,tpm,nreps,epsilon,lns,nstate,wrk,xlc,
-                   ntot,nxi,alpha,beta,gamma,xi,xisum)
+subroutine recurse(fy,xispd,tpm,nreps,epsilon,lns,nstate,nis,cis,
+                   wrk,xlc,ntot,nxi,alpha,beta,gamma,xi,xisum)
 
 implicit double precision(a-h,o-z)
-dimension xispd(nstate), xlc(ntot), lns(nreps)
+logical cis
+dimension xispd(nstate,nis), xlc(ntot), lns(nreps)
 dimension tpm(nstate,nstate), wrk(nstate,nstate)
 dimension fy(nstate,ntot), alpha(nstate,ntot), beta(nstate,ntot)
 dimension gamma(nstate,ntot), xi(nstate,nstate,nxi), xisum(nstate,nstate)
 
-# Set zero:
+# Set zero and one:
 zero = 0.d0
+one  = 1.d0
 
 # Run through the replicates.
 kstop = 0
@@ -16,13 +18,18 @@ do k = 1,nreps {
 	n = lns(k)
         nm1 = n - 1
 	kstart = 1 + kstop
+        if(cis) {
+            kis = 1
+        } else {
+            kis = k
+        }
 
 # Update the alpha's.
-	call afun(fy(1,kstart),xispd,tpm,epsilon,n,nstate,wrk,
+	call afun(fy(1,kstart),xispd(1,kis),tpm,epsilon,n,nstate,wrk,
                   xlc(kstart),alpha(1,kstart))
 
 # Update the beta's.
-	call bfun(fy(1,kstart),xispd,tpm,epsilon,n,nstate,wrk,
+	call bfun(fy(1,kstart),xispd(1,kis),tpm,epsilon,n,nstate,wrk,
                   beta(1,kstart))
 
 # Update the gamma's.
